Staples Full Strip Stapler | Staples.co.uk
Description: See pricing info, deals and product reviews for Staples Full Strip Stapler at Staples.co.uk. Order online today and get fast, free shipping for your business.

Login
User Name
Password
Remember me
Forgot your user name or password?
New to Staples.co.uk ?
Close
for your personalised pricing and offers Register Online Forgot user name/password?
Just for you Save Now ! [ Expand Deal ]
Pens | Tape | Desk Supplies > Desktop Stationery | Clips | Accessories > Staplers >
Zoom in

# Staples Full Strip Stapler

Item# WW-412852
• Colour: Black • Quantity: 1 • Staple Compatibility: 26/06/2014
Not yet rated. Be the first to Write a Review
Ex VAT
£1.94 1 Each
When you buy 6+
1 Each
Ex VAT
£2.16 Total Price
Add to Basket
Add to My List

Buy more & save!
Qty | 1 | 3 | 6
Price Ex VAT | £2.16 | £2.05 | £1.94
Save |  | 5% | 10%

Available for click & collectIn StockExpected Delivery: Next Working Day
This product can be delivered to your address, or to your nearest store for collection. Simply place the product in the shopping basket, then at the checkout either fill in your delivery address, or select "Deliver to Store", and follow the normal payment process.
Description Features Accessories

- Keeps your documents together and neatly presented
- Staples up to 20 sheets at a time
- Dimensions: 100 x 37 x 200mm
- Weight: 150g
- Staple size 26/6

Product Information
  Colour :
  Black
  Quantity :
  1
  Staple Compatibility :
  26/06/2014
  Stapling Capacity (sheets) :
  20 sheets
  Brands :
  Staples

### Accessories

### Frequently Bought Together

1 Each

### Staples Full Strip Stapler

£2.16 Ex VAT Quick Info
5000 Per Box

### Staples 26/6 Staples

£1.66 Ex VAT Quick Info
5000 Per Pack

### Staples 26/6 Staples

£2.33 Ex VAT Quick Info

### Customers also bought

### Customers also viewed

Stay in the Know.

Sign up to get email updates on the latest exclusive offers and events! Enter your email. Sign Up

Enter your email address
Please enter correct email address

Thank you for Subscribing

You will shortly receive news and promotions from Staples.
Learn more about available payment methods and security.
International Staples See all 22 international Staples websites 20+ Employee
Custom Program
Staples supplies both businesses and consumers. Prices are available both exclusive and inclusive of VAT.